==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/GetBookmarkRelationPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.GetBookmarkRelationPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property bookmarkId Bookmark ID
 * @property relationName Relation Name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property workspaceName The name of the workspace.
 */
public data class GetBookmarkRelationPlainArgs(
    public val bookmarkId: String,
    public val relationName: String,
    public val resourceGroupName: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.GetBookmarkRelationPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.GetBookmarkRelationPlainArgs =
        com.pulumi.azurenative.securityinsights.inputs.GetBookmarkRelationPlainArgs.builder()
            .bookmarkId(bookmarkId.let({ args0 -> args0 }))
            .relationName(relationName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetBookmarkRelationPlainArgs].
 */
@PulumiTagMarker
public class GetBookmarkRelationPlainArgsBuilder internal constructor() {
    private var bookmarkId: String? = null

    private var relationName: String? = null

    private var resourceGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value Bookmark ID
     */
    @JvmName("gtulsvdnagdpydkb")
    public suspend fun bookmarkId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.bookmarkId = mapped
    }

    /**
     * @param value Relation Name
     */
    @JvmName("fycqjawwkhmjnvgj")
    public suspend fun relationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.relationName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("mvplaxmhovkcahog")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("qxfoiflsirbecdku")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetBookmarkRelationPlainArgs = GetBookmarkRelationPlainArgs(
        bookmarkId = bookmarkId ?: throw PulumiNullFieldException("bookmarkId"),
        relationName = relationName ?: throw PulumiNullFieldException("relationName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/GetBookmarkRelationPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.GetBookmarkRelationPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property bookmarkId Bookmark ID
 * @property relationName Relation Name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property workspaceName The name of the workspace.
 */
public data class GetBookmarkRelationPlainArgs(
    public val bookmarkId: String,
    public val relationName: String,
    public val resourceGroupName: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.GetBookmarkRelationPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.GetBookmarkRelationPlainArgs =
        com.pulumi.azurenative.securityinsights.inputs.GetBookmarkRelationPlainArgs.builder()
            .bookmarkId(bookmarkId.let({ args0 -> args0 }))
            .relationName(relationName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetBookmarkRelationPlainArgs].
 */
@PulumiTagMarker
public class GetBookmarkRelationPlainArgsBuilder internal constructor() {
    private var bookmarkId: String? = null

    private var relationName: String? = null

    private var resourceGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value Bookmark ID
     */
    @JvmName("chhvedghgcmugwiv")
    public suspend fun bookmarkId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.bookmarkId = mapped
    }

    /**
     * @param value Relation Name
     */
    @JvmName("ghvtrexudtylqnlk")
    public suspend fun relationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.relationName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("kvikdfwddssauytw")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("audknhspigpnysnu")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetBookmarkRelationPlainArgs = GetBookmarkRelationPlainArgs(
        bookmarkId = bookmarkId ?: throw PulumiNullFieldException("bookmarkId"),
        relationName = relationName ?: throw PulumiNullFieldException("relationName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
    )
}
